// bench.cpp
// author: Krasimir Georgev, 2013

#include <iostream>
#include <algorithm>
#include <map>
#include <cassert>
using namespace std;

typedef long long int bint;
typedef pair<bint, bint> bpair;

// calculates the size of the left hole after a person sits at the middle of
// an n-bench
bint l(bint n) {
    assert (n > 0);
    return (n - 1) / 2;
}

// calculates the size of the right hole after a person sits at the middle of
// an n-bench
bint r(bint n) {
    return (n - 1) - l(n);
}

// calculates the next range of hole sizes given the previous range
bpair shrink(bpair range) {
    assert (range.first <= range.second &&
            range.second - range.first <= 2);

    bint ls = l(range.first);
    bint gt = r(range.second);
    return bpair(ls, gt);
}

// calculates the number H_s(n) of s-holes in an n-bench
bint num_holes(bint s, bint n) {
    assert (s >= 0 && n >= 0);
    
    // map for memoization
    typedef map<bpair, bint> mem_t;
    static mem_t mem;

    bint result;
    if (s == 0 || s > n) {
        result = 0;
    }
    else if (s == n) {
        result = 1;
    }
    else {
        mem_t::iterator iter = mem.find(bpair(s, n));
        if (iter != mem.end()) {
            result = iter->second;
        }
        else {
            result = num_holes(s, l(n)) + num_holes(s, r(n));
            mem[bpair(s, n)] = result;
        }
    }
    
    return result;
}

// calculates the number of holes of size greater than s in an n-bench
bint num_holes_gt(bint s, bint n) {
    assert (s > 0 && n >= 0);
    
    bint t, result = 0;
    bpair range(n, n);
    for (;;) {
        for (t = range.second; t >= range.first && t > s; --t) {
            result += num_holes(t, n);
        }
        
        if (t <= s) {
            return result;
        }
        
        range = shrink(range);
    }
}


// calculates the index (zero-based) B_s(n, i) of the beginning of the j-th
// (zero-based) s-hole in an n-bench
bint hole_start(bint s, bint n, bint j) {
    assert (s > 0 && n >= 0 && j >= 0);
    
    bint result;
    if (s == n) {
        result = 0;
    }
    else {
        bint num_l_holes = num_holes(s, l(n));
        if (j < num_l_holes) {
            result = hole_start(s, l(n), j);
        }
        else {
            result = l(n) + 1 + hole_start(s, r(n), j - num_l_holes);
        }
    }

    return result;
}


// calculates the i-th persons hole size and rank (zero-based) in an n-bench
bpair hole_info(bint n, bint i) {
    assert (1 <= i && i <= n);
    
    bint done = 0, old_done;
    bint s, old_s;
    bint hole_size, hole_rank;
    bpair range(n, n);

    for (;;) {
        for (s = range.second; s >= range.first && s > 0; --s) {
            old_s = s;
            old_done = done;
            done += num_holes(s, n);
            
            if (done >= i) {
                hole_size = old_s;
                hole_rank = i - old_done - 1;
                return make_pair(hole_size, hole_rank);
            }
        }
        range = shrink(range);
    }
}

// calculates the position of the i-th person in an n-bench
bint man_pos(bint n, bint i) {
    assert (1 <= i && i <= n);

    bpair hole = hole_info(n, i);
    bint hole_size = hole.first;
    bint hole_rank = hole.second;

    return hole_start(hole_size, n, hole_rank) + l(hole_size) + 1;
}

// calculates the index of the person sitting in the place p in an n-bench
bint man_index(bint n, bint p) {
    assert (1 <= p && p <= n);

    bint index;
    if (p == l(n) + 1) {
        index = 1;
    }
    else {
        bint hole_size, hole_rank;
        if (p <= l(n)) {
            bint l_index = man_index(l(n), p);
            bpair l_hole = hole_info(l(n), l_index);
            hole_size = l_hole.first;
            hole_rank = l_hole.second;
        }
        else {
            bint r_index = man_index(r(n), p - l(n) - 1);
            bpair r_hole = hole_info(r(n), r_index);

            hole_size = r_hole.first;
            hole_rank = num_holes(hole_size, l(n)) + r_hole.second;
        }

        index = num_holes_gt(hole_size, n) + hole_rank + 1;
    }

    return index;
}

void doit() {
    bint n, i, p;
    cin >> n >> i >> p;
    cout << man_pos(n, i) << ' ' << man_index(n, p) << endl;
}

int main() {
    doit();
    return 0;
}

